@@ -1,10 +1,12 @@
 """
 Methods that execute specific queries against the SQLite database for the ACTIONS table.
-This supports the policy_sentry query functionality
+This supports the Policy Sentry query functionality
 """
 import logging
 from policy_sentry.shared.iam_data import iam_definition, get_service_prefix_data
 from policy_sentry.querying.all import get_all_service_prefixes
+from policy_sentry.querying.arns import get_matching_raw_arn, get_resource_type_name_with_raw_arn
+from policy_sentry.util.arns import get_service_from_arn
 
 all_service_prefixes = get_all_service_prefixes()
 logger = logging.getLogger(__name__)
@@ -189,6 +191,23 @@ def get_actions_with_arn_type_and_access_level(
     return results
 
 
+def get_actions_matching_arn(arn):
+    """Given a user-supplied arn, get a list of all actions that can match it."""
+    raw_arn = get_matching_raw_arn(arn)
+    resource_type_name = get_resource_type_name_with_raw_arn(raw_arn)
+    service_prefix = get_service_from_arn(raw_arn)
+    service_prefix_data = get_service_prefix_data(service_prefix)
+    results = []
+    for some_action in service_prefix_data["privileges"]:
+        for some_resource_type in some_action["resource_types"]:
+            this_resource_type = some_resource_type["resource_type"].strip("*")
+            if this_resource_type.lower() == resource_type_name.lower():
+                results.append(f"{service_prefix}:{some_action['privilege']}")
+    results = list(dict.fromkeys(results))
+    results.sort()
+    return results
+
+
 def get_actions_matching_condition_key(service_prefix, condition_key):
     """
     Get a list of actions under a service that allow the use of a specified condition key
@@ -256,9 +275,19 @@ def remove_actions_not_matching_access_level(actions_list, access_level):
             return False
         else:
             return this_result
-
+    if actions_list == ["*"]:
+        actions_list.clear()
+        for some_prefix in all_service_prefixes:
+            service_prefix_data = get_service_prefix_data(some_prefix)
+            for some_action in service_prefix_data["privileges"]:
+                if some_action["access_level"] == access_level:
+                    actions_list.append(f"{some_prefix}:{some_action['privilege']}")
     for action in actions_list:
-        service_prefix, action_name = action.split(":")
+        try:
+            service_prefix, action_name = action.split(":")
+        except ValueError as v_e:
+            logger.debug(f"{v_e} - for action {action}")
+            continue
         result = is_access_level(service_prefix, action_name)
         if result:
             new_actions_list.append(result)
